@@ -80,13 +80,6 @@ Available commands:
         parser.add_option("-K", "--no-kid-support", default=True,
             action="store_false", dest="kid_support",
             help="Do not extract messages from Kid templates")
-        parser.add_option("", "--loose-kid-support",
-            action="store_true", dest="loose_kid_support",
-            help="Extract ALL messages from Kid templates (this is default)")
-        parser.add_option("", "--strict-kid-support",
-            action="store_false", dest="loose_kid_support",
-            help="Extract only messages marked with lang attribute"
-                " from Kid templates")
         parser.add_option("", "--src-dir", default=None,
             action="store", dest="source_dir",
             help="Directory that contains source files")
@@ -101,7 +94,7 @@ Available commands:
         parser.add_option("-e", "--js-encoding",
             dest="js_encoding", default="utf-8", metavar="ENCODING",
             help="Encoding of JavaScript source files (default: UTF-8)")
-        parser.set_defaults(loose_kid_support=True, js_support=True)
+        parser.set_defaults(js_support=True)
         self.parser = parser
 
     def load_project_config(self):
@@ -312,7 +305,6 @@ for(var i in _messages) {
         atexit.register(silent_os_remove, tmp_potfile)
         if kid_files and self.options.kid_support:
             self.scan_kid_files(tmp_potfile, kid_files)
-
         if js_files and self.options.js_support:
             self.scan_js_files(tmp_potfile, js_files)
         potfile = self.get_potfile_path()
