@@ -1,17 +1,20 @@
 # coding=UTF-8
+
 import re
 import unittest
 import urllib
 import base64
+
 import formencode
 import cherrypy
+
 from turbogears import testutil, database, identity, config, startup, expose
 from turbogears.controllers import Controller, RootController
 from turbogears.identity import SecureResource, \
     has_permission, in_group, not_anonymous
 from turbogears.identity.soprovider import TG_User, TG_Group, TG_Permission
 
-#hub = database.AutoConnectHub("sqlite:///:memory:")
+# hub = database.AutoConnectHub("sqlite:///:memory:")
 hub = database.PackageHub("turbogears.identity")
 
 try:
@@ -151,6 +154,7 @@ class TestIdentity(unittest.TestCase):
         test_config = {'global': {
             'visit.on': True, 'identity.on': True,
             'identity.failure_url': '/identity_failed',
+            'identity.force_external_redirect': False,
             'identity.soprovider.encryption_algorithm': None}}
         original_config = dict()
         for key in test_config['global']:
@@ -357,6 +361,33 @@ class TestIdentity(unittest.TestCase):
         firstline = cherrypy.response.body[0]
         assert 'logged_in_only' in firstline, firstline
 
+    def test_external_redirect(self):
+        """Test that external redirection at identity failures works."""
+        config.update({'identity.failure_url': 'test_login',
+            'identity.force_external_redirect': True})
+        testutil.create_request('/logged_in_only?a=1&b=2')
+        firstline = cherrypy.response.body[0]
+        assert 'identity_failed_answer' not in firstline, firstline
+        path, params = cherrypy.response.headers['Location'].split('?', 1)
+        assert path.endswith('/test_login')
+        params = params.split('&')
+        params.sort()
+        params = '&'.join(params)
+        assert params == 'a=1&b=2&forward_url=%2Flogged_in_only'
+
+    def test_external_redirect_with_funky_params(self):
+        """Test that external redirection properly handles funky parameters."""
+        config.update({'identity.force_external_redirect': True})
+        testutil.create_request('/logged_in_only?'
+            'a-0.x=1&a-0.y=2&a-1.x=3&a-1.y=4')
+        path, params = cherrypy.response.headers['Location'].split('?', 1)
+        assert path.endswith('/identity_failed')
+        params = params.split('&')
+        params.sort()
+        params = '&'.join(params)
+        assert params == ('a-0.x=1&a-0.y=2&a-1.x=3&a-1.y=4'
+            '&forward_url=%2Flogged_in_only')
+
     def test_basic_authentication(self):
         """Test HTTP basic authentication mechanism."""
         credentials = base64.encodestring('samIam:secret')[:-1]
@@ -403,7 +434,8 @@ class TestIdentity(unittest.TestCase):
         assert request.identity.anonymous
 
     def test_require_group(self):
-        """Test that a anonymous user"""
+        """Test that an anonymous user can not access resource protected by
+        require(in_group(...))"""
         testutil.create_request('/in_peon_group')
         firstline = cherrypy.response.body[0]
         assert 'identity_failed_answer' in firstline, firstline
