@@ -54,7 +54,7 @@ def create_extension_model():
 
 class IdentityVisitPlugin(object):
     def __init__(self):
-        log.info("Identity visit plugin initialised")
+        log.info("Identity visit plugin initialized")
         get = turbogears.config.get
 
         self.provider = create_default_provider()
