@@ -730,7 +730,14 @@ def create_tables():
         'addresses': relation(Address, backref='user', lazy=False)})
     mapper(Address, addresses_table)
 
-    metadata.create_all()
+    try:
+        metadata.create_all()
+    except Exception, error:
+        # workaround for a problem with PySqlite < 2.6 and SQLAlchemy < 0.5
+        if 'Cannot operate on a closed cursor' in str(error):
+            metadata.create_all(checkfirst=False)
+        else:
+            raise
 
     occupations = (
         {'id': 1, 'name': 'Doctor'},
